===
API
===

--------
Machines
--------

.. autoclass:: automaton.machines.State
    :members:

.. autoclass:: automaton.machines.FiniteMachine
    :members:
    :special-members: __iter__, __contains__

.. autoclass:: automaton.machines.HierarchicalFiniteMachine
    :noindex:
    :members:

-------
Runners
-------

.. autoclass:: automaton.runners.Runner
    :members:

.. autoclass:: automaton.runners.FiniteRunner
    :members:

.. autoclass:: automaton.runners.HierarchicalRunner
    :members:

----------
Converters
----------

.. automodule:: automaton.converters.pydot
    :members:

----------
Exceptions
----------

.. automodule:: automaton.exceptions
    :members:

Hierarchy
---------

.. inheritance-diagram::
    automaton.exceptions
    :parts: 1
